import xml.etree.ElementTree as ET
import sys
import json
from PIL import Image
import os
from pathlib import Path

def pxToUnit(root, px):
    width = float(root.attrib['width'])
    viewBox = root.attrib['view-box'].split()
    areaWidth = abs(float(viewBox[0])) + abs(float(viewBox[2]))
    return px / (width / areaWidth) 

def createGroup(canvas, desc = ""):
    parent = ET.fromstring(''' 
 <layer type="group" active="true" exclude_from_rendering="false" version="0.3">
    <param name="z_depth">
      <real value="0.0000000000"/>
    </param>
    <param name="amount">
      <real value="1.0000000000"/>
    </param>
    <param name="blend_method">
      <integer value="0" static="true"/>
    </param>
    <param name="origin">
      <vector>
        <x>0.0000000000</x>
        <y>0.0000000000</y>
      </vector>
    </param>
    <param name="transformation">
      <composite type="transformation">
        <offset>
          <vector>
            <x>0.0000000000</x>
            <y>0.0000000000</y>
          </vector>
        </offset>
        <angle>
          <angle value="0.000000"/>
        </angle>
        <skew_angle>
          <angle value="0.000000"/>
        </skew_angle>
        <scale>
          <vector>
            <x>1.0000000000</x>
            <y>1.0000000000</y>
          </vector>
        </scale>
      </composite>
    </param>
    <param name="canvas">
    </param>
    <param name="time_dilation">
      <real value="1.0000000000"/>
    </param>
    <param name="time_offset">
      <time value="0s"/>
    </param>
    <param name="children_lock">
      <bool value="true" static="true"/>
    </param>
    <param name="outline_grow">
      <real value="0.0000000000"/>
    </param>
    <param name="z_range">
      <bool value="false" static="true"/>
    </param>
    <param name="z_range_position">
      <real value="0.0000000000"/>
    </param>
    <param name="z_range_depth">
      <real value="0.0000000000"/>
    </param>
    <param name="z_range_blur">
      <real value="0.0000000000"/>
    </param>
</layer>
  ''')
    parent.attrib['desc'] = desc
    ET.SubElement(parent[5], 'canvas')
    parent[5][0].append(canvas)
    return parent

def createImage(desc, imagePath ):
    image = ET.fromstring('''    
        <layer type="import" active="true" exclude_from_rendering="false" version="0.1" desc="">
            <param name="z_depth">
                <real value="0.0000000000"/>
            </param>
            <param name="amount">
                <real value="1.0000000000"/>
            </param>
            <param name="blend_method">
                <integer value="0" static="true"/>
            </param>
            <param name="tl">
                <vector>
                    <x></x>
                    <y></y>
                </vector>
            </param>
            <param name="br">
                <vector>
                    <x></x>
                    <y></y>
                </vector>
            </param>
            <param name="c">
                <integer value="1" static="true"/>
            </param>
            <param name="gamma_adjust">
                <real value="1.0000000000"/>
            </param>
            <param name="filename">
                <string></string>
            </param>
            <param name="time_offset">
            <time value="0s"/>
            </param>
        </layer>
        ''')
    image.attrib['desc'] = desc 
    image[7][0].text = imagePath
    with Image.open(imagePath) as img:
        width, height = img.size
    print(width, height)
    image[3][0][0].text = str(0)
    image[3][0][1].text = str(0)
    image[4][0][0].text = str(pxToUnit(root, width))
    image[4][0][1].text = str(-(pxToUnit(root, height)))

    return image

def createImageGroup(desc ,imagePath, positionOffset, offset):
    image = createImage(desc, imagePath)
    parent = createGroup(image, desc)
    parent[4][0][0][0][0].text = str(pxToUnit(root, positionOffset[0] + -1920/2))
    parent[4][0][0][0][1].text = str(pxToUnit(root, -positionOffset[1] + 1080/2))
    return parent

if os.path.isfile(sys.argv[2]):
  print("File exists")
else:
  f = open(sys.argv[2], "a")
  f.write('''<?xml version="1.0" encoding="UTF-8"?>
    <canvas version="1.2" width="480" height="270" xres="2834.645669" yres="2834.645669" gamma-r="1.000000" gamma-g="1.000000" gamma-b="1.000000" view-box="-4.000000 2.250000 4.000000 -2.250000" antialias="1" fps="24.000" begin-time="0f" end-time="5s" bgcolor="0.500000 0.500000 0.500000 1.000000">
      <name>tempTest.sif</name>
      <meta name="background_first_color" content="0.880000 0.880000 0.880000"/>
      <meta name="background_rendering" content="0"/>
      <meta name="background_second_color" content="0.650000 0.650000 0.650000"/>
      <meta name="background_size" content="15.000000 15.000000"/>
      <meta name="grid_color" content="0.623529 0.623529 0.623529"/>
      <meta name="grid_show" content="0"/>
      <meta name="grid_size" content="0.250000 0.250000"/>
      <meta name="grid_snap" content="0"/>
      <meta name="guide_color" content="0.435294 0.435294 1.000000"/>
      <meta name="guide_show" content="1"/>
      <meta name="guide_snap" content="0"/>
      <meta name="jack_offset" content="0.000000"/>
      <meta name="onion_skin" content="0"/>
      <meta name="onion_skin_future" content="0"/>
      <meta name="onion_skin_keyframes" content="1"/>
      <meta name="onion_skin_past" content="1"/>
      <keyframe time="0f" active="true"/>
    </canvas>''')
  f.close()

f = open(sys.argv[1])
spriteInfo = json.load(f)
tree = ET.parse(sys.argv[2])
root = tree.getroot()
layers = []
path = Path(sys.argv[1])
parent = path.parent.absolute()
for item in spriteInfo['nodes']:
    layers.insert(0, createImageGroup(item['name'], os.path.join(parent, Path(item['resource_path'])), item['position'], item['offset']))
root.extend(layers)

tr2ee = ET.ElementTree(root)
with open(sys.argv[2], "wb") as fh:
    tr2ee.write(fh)